/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-1999 Netscape Communications Corporation. All
 * Rights Reserved.
 */

#include "nsISupports.idl"

interface nsIAuthPrompt;

[scriptable, uuid(c165b634-1dd1-11b2-a849-82dd67b7519e)]
interface nsISmtpServer : nsISupports {
    
    attribute string key;       // unique identifier
    
    attribute string hostname;
    attribute PRInt32 port;
    attribute string username;
    attribute string password;
    readonly attribute string displayname;

    /* what kind of logon redirector to use for this server, if any */
    attribute string redirectorType;   

    attribute long authMethod;
    readonly attribute boolean trySecAuth;
    attribute long trySSL;

    readonly attribute string serverURI;
    string getPasswordWithUI(in wstring promptString, in wstring promptTitle,
                             in nsIAuthPrompt netPrompt);
    void getUsernamePasswordWithUI(in wstring promptString, in wstring promptTitle,
                             in nsIAuthPrompt netPrompt, out string userid, out string password);
    void forgetPassword();

	void clearAllValues();
};
